@@ -16,6 +16,6 @@ For Polar Parallel Coordinates Plots (P2CPs), many datasets are available throug
 `scikit-learn <https://scikit-learn.org/stable/datasets.html>`_.
 """
 
-from hiveplotlib.datasets.international_trade import *  # noqa: F401, F403
-from hiveplotlib.datasets.toy_hive_plots import *  # noqa: F401, F403
-from hiveplotlib.datasets.toy_p2cps import *  # noqa: F401, F403
+from hiveplotlib.datasets.international_trade import *  # noqa: F403
+from hiveplotlib.datasets.toy_hive_plots import *  # noqa: F403
+from hiveplotlib.datasets.toy_p2cps import *  # noqa: F403
