@@ -8,9 +8,8 @@ try:
     from bokeh.models import ColumnDataSource, Label, Range1d
     from bokeh.plotting import figure
 except ImportError as ie:  # pragma: no cover
-    raise ImportError(
-        "bokeh not installed, but can be installed by running `pip install hiveplotlib[bokeh]`"
-    ) from ie
+    msg = "bokeh not installed, but can be installed by running `pip install hiveplotlib[bokeh]`"
+    raise ImportError(msg) from ie
 
 import warnings
 from typing import Hashable, List, Literal, Optional, Union
@@ -606,7 +605,7 @@ def edge_viz(
                     hive_plot.edges.to_column_name,
                 ]
                 else ""
-                for i in hive_plot.edges._data[list(tags_to_plot)[0]].columns
+                for i in hive_plot.edges._data[next(iter(tags_to_plot))].columns
             ]
             right_arrow = "&#x27A1;"
             tooltips = f"""
