@@ -4,16 +4,13 @@
 Currently, ``hiveplotlib`` supports a ``bokeh`` and ``matplotlib`` backend for ``holoviews``.
 """
 
-# __all__ = []
-
 try:
     import holoviews as hv
     from bokeh.models import HoverTool
     from holoviews import dim
 except ImportError as ie:  # pragma: no cover
-    raise ImportError(
-        "`holoviews` not installed, but can be installed by running `pip install hiveplotlib[holoviews]`"
-    ) from ie
+    msg = "`holoviews` not installed, but can be installed by running `pip install hiveplotlib[holoviews]`"
+    raise ImportError(msg) from ie
 
 import warnings
 from typing import Hashable, List, Literal, Optional, Union, get_args
@@ -262,7 +259,7 @@ def axes_viz(
         kdims=[original_to_sanitized_map[i] for i in ["x_0", "y_0", "x_1", "y_1"]],
         vdims=[
             original_to_sanitized_map[i]
-            for i in ["long_name"] + list(axis_metadata_variables)
+            for i in ["long_name", *list(axis_metadata_variables)]
             if i not in ["x_0", "x_1", "y_0", "y_1"]
         ],
     ).opts(
@@ -647,10 +644,13 @@ def edge_viz(
                         | hive_plot.hive_plot_edges[a0][a1][tag]["edge_kwargs"]
                     )
                     if backend == "bokeh" and "line_color" in final_edge_kwargs:
-                        raise ValueError(
+                        msg = (
                             "Hiveplotlib does not support using the 'line_color' parameter"
                             " with the `holoviews-bokeh` backend. "
-                            "Please switch to using the 'color' parameter instead.",
+                            "Please switch to using the 'color' parameter instead."
+                        )
+                        raise ValueError(
+                            msg,
                         )
                     # if any kwarg value corresponds to an edge data column name, use the edge data values
                     keys_vals = final_edge_kwargs.copy().items()
@@ -693,7 +693,9 @@ def edge_viz(
                         ]
                         contours = [
                             {"x": x, "y": y, **data_dict}
-                            for (x, y, data_dict) in zip(xs, ys, data_dicts)
+                            for (x, y, data_dict) in zip(
+                                xs, ys, data_dicts, strict=True
+                            )
                         ]
 
                         # HACK: solution to https://github.com/holoviz/holoviews/issues/6469 for the moment
@@ -740,7 +742,7 @@ def edge_viz(
                     hive_plot.edges.to_column_name,
                 ]
                 else ""
-                for i in hive_plot.edges._data[list(tags_to_plot)[0]].columns
+                for i in hive_plot.edges._data[next(iter(tags_to_plot))].columns
             ]
             right_arrow = "&#x27A1;"
             tooltips = f"""
