@@ -58,7 +58,7 @@ def _matplotlib_fig_setup(
         fig, ax = plt.subplots(**fig_kwargs)
 
     if center_plot and hive_plot.max_polar_end is not None:
-        ax.axis("equal")
+        ax.set_aspect("equal", adjustable="box")
         # center plot at (0, 0)
         max_radius = hive_plot.max_polar_end
         # throw in a minor buffer
